////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Copyright (c) Qualcomm Technologies, Inc. and/or its subsidiaries.
// All Rights Reserved.
// Confidential and Proprietary - Qualcomm Technologies, Inc.
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// THIS IS AUTO-GENERATED CODE.  PLEASE DO NOT EDIT (File bug reports against tools).
///
/// Auto-generated by: Parameter Parser V5.5.1 (2411131018)
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @file  modtemporalawbv1.cpp
/// @brief Auto-generated Chromatix parameter file
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#include "modtemporalawbv1.h"
#include "parametersetmanager.h"

MODTEMPORALAWBV1_NAMESPACE_BEGIN

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// SetValue/GetValue Functions
/// Gets or sets the requested value
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool HistoryResolutionType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "hor") == 0)
    {
        if (__index < horCount)
        {
            ParameterUtils::DoubleToString((double)hor[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < horCount; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)hor[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }
    else if (PARAMETER_STRCMP(__name, "vert") == 0)
    {
        if (__index < vertCount)
        {
            ParameterUtils::DoubleToString((double)vert[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < vertCount; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)vert[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool HistoryResolutionType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "hor") == 0)
    {
        if (__index < horCount)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                hor[__index] = (INT32)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < horCount)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    hor[__index] = (INT32)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }
    else if (PARAMETER_STRCMP(__name, "vert") == 0)
    {
        if (__index < vertCount)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                vert[__index] = (INT32)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < vertCount)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    vert[__index] = (INT32)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool HistoryResolutionType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // hor
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hor", ParameterParserDataType::Int32, true, false, horCount));
    }

    // vert
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("vert", ParameterParserDataType::Int32, true, false, vertCount));
    }

    return __result;
}

bool HistoryConfigType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "histResolution") == 0)
    {
        __result = histResolution.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "sceneChangeRGBGTh") == 0)
    {
        ParameterUtils::DoubleToString((double)sceneChangeRGBGTh, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "sceneChangeLuxTh") == 0)
    {
        ParameterUtils::DoubleToString((double)sceneChangeLuxTh, __value, __size);
        __result = true;
    }

    return __result;
}

bool HistoryConfigType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "histResolution") == 0)
    {
        __result = histResolution.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "sceneChangeRGBGTh") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            sceneChangeRGBGTh = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "sceneChangeLuxTh") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            sceneChangeLuxTh = (float)dblValue; 
        }
    }

    return __result;
}

bool HistoryConfigType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // histResolution
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("histResolution", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "histResolution") == 0)
    {
        __result = histResolution.GetInfo(&__path[__pos], __info);
    }

    // sceneChangeRGBGTh
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("sceneChangeRGBGTh", ParameterParserDataType::Float, (double)sceneChangeRGBGTh));
    }
    else if (PARAMETER_STRCMP(__name, "sceneChangeRGBGTh") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)sceneChangeRGBGTh));
    }

    // sceneChangeLuxTh
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("sceneChangeLuxTh", ParameterParserDataType::Float, (double)sceneChangeLuxTh));
    }
    else if (PARAMETER_STRCMP(__name, "sceneChangeLuxTh") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)sceneChangeLuxTh));
    }

    return __result;
}

bool WeightLUTGrayRatioTriggerType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "triggerPt") == 0)
    {
        __result = triggerPt.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "triggerData") == 0)
    {
        __result = triggerData.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool WeightLUTGrayRatioTriggerType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "triggerPt") == 0)
    {
        __result = triggerPt.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "triggerData") == 0)
    {
        __result = triggerData.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool WeightLUTGrayRatioTriggerType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // triggerPt
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("triggerPt", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "triggerPt") == 0)
    {
        __result = triggerPt.GetInfo(&__path[__pos], __info);
    }

    // triggerData
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("triggerData", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "triggerData") == 0)
    {
        __result = triggerData.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool WeightLUTFOVChangeTriggerType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "triggerPt") == 0)
    {
        __result = triggerPt.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "triggerData") == 0)
    {
        if (__index < triggerDataCount)
        {
            __result = triggerData[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool WeightLUTFOVChangeTriggerType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "triggerPt") == 0)
    {
        __result = triggerPt.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "triggerData") == 0)
    {
        if (__index < triggerDataCount)
        {
            __result = triggerData[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool WeightLUTFOVChangeTriggerType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // triggerPt
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("triggerPt", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "triggerPt") == 0)
    {
        __result = triggerPt.GetInfo(&__path[__pos], __info);
    }

    // triggerData
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("triggerData", ParameterParserDataType::Structure, true, false, triggerDataCount));
    }
    else if (PARAMETER_STRCMP(__name, "triggerData") == 0)
    {
        if (__index < triggerDataCount)
        {
            __result = triggerData[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, triggerDataCount));
        }
    }

    return __result;
}

bool WeightLUTLuxTriggerType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "triggerPt") == 0)
    {
        __result = triggerPt.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "triggerData") == 0)
    {
        if (__index < triggerDataCount)
        {
            __result = triggerData[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool WeightLUTLuxTriggerType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "triggerPt") == 0)
    {
        __result = triggerPt.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "triggerData") == 0)
    {
        if (__index < triggerDataCount)
        {
            __result = triggerData[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool WeightLUTLuxTriggerType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // triggerPt
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("triggerPt", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "triggerPt") == 0)
    {
        __result = triggerPt.GetInfo(&__path[__pos], __info);
    }

    // triggerData
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("triggerData", ParameterParserDataType::Structure, true, false, triggerDataCount));
    }
    else if (PARAMETER_STRCMP(__name, "triggerData") == 0)
    {
        if (__index < triggerDataCount)
        {
            __result = triggerData[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, triggerDataCount));
        }
    }

    return __result;
}

bool WeightLUTTriggerType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "triggerPt") == 0)
    {
        __result = triggerPt.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "triggerData") == 0)
    {
        if (__index < triggerDataCount)
        {
            __result = triggerData[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool WeightLUTTriggerType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "triggerPt") == 0)
    {
        __result = triggerPt.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "triggerData") == 0)
    {
        if (__index < triggerDataCount)
        {
            __result = triggerData[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool WeightLUTTriggerType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // triggerPt
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("triggerPt", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "triggerPt") == 0)
    {
        __result = triggerPt.GetInfo(&__path[__pos], __info);
    }

    // triggerData
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("triggerData", ParameterParserDataType::Structure, true, false, triggerDataCount));
    }
    else if (PARAMETER_STRCMP(__name, "triggerData") == 0)
    {
        if (__index < triggerDataCount)
        {
            __result = triggerData[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, triggerDataCount));
        }
    }

    return __result;
}

bool DecisionsAggBasedType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "weight") == 0)
    {
        __result = weight.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "historyConfig") == 0)
    {
        __result = historyConfig.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool DecisionsAggBasedType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "weight") == 0)
    {
        __result = weight.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "historyConfig") == 0)
    {
        __result = historyConfig.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool DecisionsAggBasedType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // weight
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("weight", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "weight") == 0)
    {
        __result = weight.GetInfo(&__path[__pos], __info);
    }

    // historyConfig
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("historyConfig", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "historyConfig") == 0)
    {
        __result = historyConfig.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool DecisionGeneralParamsType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "histUpdateTolerance") == 0)
    {
        ParameterUtils::DoubleToString((double)histUpdateTolerance, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool DecisionGeneralParamsType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "histUpdateTolerance") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            histUpdateTolerance = (INT32)dblValue; 
        }
    }

    return __result;
}

bool DecisionGeneralParamsType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // histUpdateTolerance
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("histUpdateTolerance", ParameterParserDataType::Int32, (double)histUpdateTolerance, 0));
    }
    else if (PARAMETER_STRCMP(__name, "histUpdateTolerance") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)histUpdateTolerance, 0));
    }

    return __result;
}

bool TemporalDecisionConfigType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "generalParams") == 0)
    {
        __result = generalParams.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "aggregation") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)aggregation, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "decisionsAggBased") == 0)
    {
        __result = decisionsAggBased.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool TemporalDecisionConfigType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "generalParams") == 0)
    {
        __result = generalParams.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "aggregation") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            aggregation = (DecisionAggrType)(UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "decisionsAggBased") == 0)
    {
        __result = decisionsAggBased.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool TemporalDecisionConfigType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // generalParams
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("generalParams", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "generalParams") == 0)
    {
        __result = generalParams.GetInfo(&__path[__pos], __info);
    }

    // aggregation
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aggregation", ParameterParserDataType::Enum, (double)(UINT32)aggregation, 0));
    }
    else if (PARAMETER_STRCMP(__name, "aggregation") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)aggregation, 0));
    }

    // decisionsAggBased
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("decisionsAggBased", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "decisionsAggBased") == 0)
    {
        __result = decisionsAggBased.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool SCGeneralParamsType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "initFrameSkipCnt") == 0)
    {
        ParameterUtils::DoubleToString((double)initFrameSkipCnt, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "globalSCFrameSkipCnt") == 0)
    {
        ParameterUtils::DoubleToString((double)globalSCFrameSkipCnt, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool SCGeneralParamsType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "initFrameSkipCnt") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            initFrameSkipCnt = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "globalSCFrameSkipCnt") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            globalSCFrameSkipCnt = (INT32)dblValue; 
        }
    }

    return __result;
}

bool SCGeneralParamsType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // initFrameSkipCnt
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("initFrameSkipCnt", ParameterParserDataType::Int32, (double)initFrameSkipCnt, 0));
    }
    else if (PARAMETER_STRCMP(__name, "initFrameSkipCnt") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)initFrameSkipCnt, 0));
    }

    // globalSCFrameSkipCnt
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("globalSCFrameSkipCnt", ParameterParserDataType::Int32, (double)globalSCFrameSkipCnt, 0));
    }
    else if (PARAMETER_STRCMP(__name, "globalSCFrameSkipCnt") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)globalSCFrameSkipCnt, 0));
    }

    return __result;
}

bool GlobalSceneChangeParamsType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "AFDistSCEnable") == 0)
    {
        ParameterUtils::DoubleToString((double)AFDistSCEnable, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "contSCEnable") == 0)
    {
        ParameterUtils::DoubleToString((double)contSCEnable, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "contSCmaxTimeTh") == 0)
    {
        ParameterUtils::DoubleToString((double)contSCmaxTimeTh, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "samePosSCEnable") == 0)
    {
        ParameterUtils::DoubleToString((double)samePosSCEnable, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool GlobalSceneChangeParamsType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "AFDistSCEnable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            AFDistSCEnable = (BOOL)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "contSCEnable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            contSCEnable = (BOOL)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "contSCmaxTimeTh") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            contSCmaxTimeTh = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "samePosSCEnable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            samePosSCEnable = (BOOL)dblValue; 
        }
    }

    return __result;
}

bool GlobalSceneChangeParamsType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // AFDistSCEnable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("AFDistSCEnable", ParameterParserDataType::Boolean, (double)AFDistSCEnable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "AFDistSCEnable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Boolean, (double)AFDistSCEnable, 0));
    }

    // contSCEnable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("contSCEnable", ParameterParserDataType::Boolean, (double)contSCEnable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "contSCEnable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Boolean, (double)contSCEnable, 0));
    }

    // contSCmaxTimeTh
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("contSCmaxTimeTh", ParameterParserDataType::Int32, (double)contSCmaxTimeTh, 0));
    }
    else if (PARAMETER_STRCMP(__name, "contSCmaxTimeTh") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)contSCmaxTimeTh, 0));
    }

    // samePosSCEnable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("samePosSCEnable", ParameterParserDataType::Boolean, (double)samePosSCEnable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "samePosSCEnable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Boolean, (double)samePosSCEnable, 0));
    }

    return __result;
}

bool GlobalSceneChangeType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "luxSCDetector") == 0)
    {
        __result = luxSCDetector.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "accSCDetector") == 0)
    {
        __result = accSCDetector.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "sceneChangeParams") == 0)
    {
        __result = sceneChangeParams.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool GlobalSceneChangeType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "luxSCDetector") == 0)
    {
        __result = luxSCDetector.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "accSCDetector") == 0)
    {
        __result = accSCDetector.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "sceneChangeParams") == 0)
    {
        __result = sceneChangeParams.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool GlobalSceneChangeType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // luxSCDetector
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("luxSCDetector", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "luxSCDetector") == 0)
    {
        __result = luxSCDetector.GetInfo(&__path[__pos], __info);
    }

    // accSCDetector
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("accSCDetector", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "accSCDetector") == 0)
    {
        __result = accSCDetector.GetInfo(&__path[__pos], __info);
    }

    // sceneChangeParams
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("sceneChangeParams", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "sceneChangeParams") == 0)
    {
        __result = sceneChangeParams.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool LocalSceneChangeType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "luxSCDetector") == 0)
    {
        __result = luxSCDetector.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "orientSCDetector") == 0)
    {
        __result = orientSCDetector.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool LocalSceneChangeType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "luxSCDetector") == 0)
    {
        __result = luxSCDetector.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "orientSCDetector") == 0)
    {
        __result = orientSCDetector.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool LocalSceneChangeType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // luxSCDetector
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("luxSCDetector", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "luxSCDetector") == 0)
    {
        __result = luxSCDetector.GetInfo(&__path[__pos], __info);
    }

    // orientSCDetector
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("orientSCDetector", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "orientSCDetector") == 0)
    {
        __result = orientSCDetector.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool SceneChangeConfigType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "localSCDetector") == 0)
    {
        __result = localSCDetector.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "globalSCDetector") == 0)
    {
        __result = globalSCDetector.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "generalParams") == 0)
    {
        __result = generalParams.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool SceneChangeConfigType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "localSCDetector") == 0)
    {
        __result = localSCDetector.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "globalSCDetector") == 0)
    {
        __result = globalSCDetector.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "generalParams") == 0)
    {
        __result = generalParams.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool SceneChangeConfigType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // localSCDetector
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("localSCDetector", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "localSCDetector") == 0)
    {
        __result = localSCDetector.GetInfo(&__path[__pos], __info);
    }

    // globalSCDetector
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("globalSCDetector", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "globalSCDetector") == 0)
    {
        __result = globalSCDetector.GetInfo(&__path[__pos], __info);
    }

    // generalParams
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("generalParams", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "generalParams") == 0)
    {
        __result = generalParams.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool ImageConfigType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "inputType") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)inputType, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "scale_x") == 0)
    {
        ParameterUtils::DoubleToString((double)scale_x, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "scale_y") == 0)
    {
        ParameterUtils::DoubleToString((double)scale_y, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "confThresholdCVP") == 0)
    {
        ParameterUtils::DoubleToString((double)confThresholdCVP, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "validateUsingIMU") == 0)
    {
        ParameterUtils::DoubleToString((double)validateUsingIMU, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "weightImage") == 0)
    {
        __result = weightImage.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool ImageConfigType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "inputType") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            inputType = (ImageOrienInputType)(UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "scale_x") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            scale_x = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "scale_y") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            scale_y = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "confThresholdCVP") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            confThresholdCVP = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "validateUsingIMU") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            validateUsingIMU = (BOOL)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "weightImage") == 0)
    {
        __result = weightImage.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool ImageConfigType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // inputType
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("inputType", ParameterParserDataType::Enum, (double)(UINT32)inputType, 0));
    }
    else if (PARAMETER_STRCMP(__name, "inputType") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)inputType, 0));
    }

    // scale_x
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("scale_x", ParameterParserDataType::Float, (double)scale_x));
    }
    else if (PARAMETER_STRCMP(__name, "scale_x") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)scale_x));
    }

    // scale_y
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("scale_y", ParameterParserDataType::Float, (double)scale_y));
    }
    else if (PARAMETER_STRCMP(__name, "scale_y") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)scale_y));
    }

    // confThresholdCVP
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("confThresholdCVP", ParameterParserDataType::Float, (double)confThresholdCVP));
    }
    else if (PARAMETER_STRCMP(__name, "confThresholdCVP") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)confThresholdCVP));
    }

    // validateUsingIMU
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("validateUsingIMU", ParameterParserDataType::Boolean, (double)validateUsingIMU, 0));
    }
    else if (PARAMETER_STRCMP(__name, "validateUsingIMU") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Boolean, (double)validateUsingIMU, 0));
    }

    // weightImage
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("weightImage", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "weightImage") == 0)
    {
        __result = weightImage.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool SegmentIntegrateConfigType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable") == 0)
    {
        ParameterUtils::DoubleToString((double)enable, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "noiseThreshold_x") == 0)
    {
        ParameterUtils::DoubleToString((double)noiseThreshold_x, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "noiseThreshold_y") == 0)
    {
        ParameterUtils::DoubleToString((double)noiseThreshold_y, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "noiseThreshold_z") == 0)
    {
        ParameterUtils::DoubleToString((double)noiseThreshold_z, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "sampleCntThreshold") == 0)
    {
        ParameterUtils::DoubleToString((double)sampleCntThreshold, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool SegmentIntegrateConfigType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            enable = (BOOL)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "noiseThreshold_x") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            noiseThreshold_x = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "noiseThreshold_y") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            noiseThreshold_y = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "noiseThreshold_z") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            noiseThreshold_z = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "sampleCntThreshold") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            sampleCntThreshold = (INT32)dblValue; 
        }
    }

    return __result;
}

bool SegmentIntegrateConfigType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // enable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("enable", ParameterParserDataType::Boolean, (double)enable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "enable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Boolean, (double)enable, 0));
    }

    // noiseThreshold_x
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("noiseThreshold_x", ParameterParserDataType::Float, (double)noiseThreshold_x));
    }
    else if (PARAMETER_STRCMP(__name, "noiseThreshold_x") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)noiseThreshold_x));
    }

    // noiseThreshold_y
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("noiseThreshold_y", ParameterParserDataType::Float, (double)noiseThreshold_y));
    }
    else if (PARAMETER_STRCMP(__name, "noiseThreshold_y") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)noiseThreshold_y));
    }

    // noiseThreshold_z
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("noiseThreshold_z", ParameterParserDataType::Float, (double)noiseThreshold_z));
    }
    else if (PARAMETER_STRCMP(__name, "noiseThreshold_z") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)noiseThreshold_z));
    }

    // sampleCntThreshold
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("sampleCntThreshold", ParameterParserDataType::Int32, (double)sampleCntThreshold, 0));
    }
    else if (PARAMETER_STRCMP(__name, "sampleCntThreshold") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)sampleCntThreshold, 0));
    }

    return __result;
}

bool OffsetScaleConfigType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "offsetScale_x") == 0)
    {
        ParameterUtils::DoubleToString((double)offsetScale_x, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "offsetScale_y") == 0)
    {
        ParameterUtils::DoubleToString((double)offsetScale_y, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "offsetScale_z") == 0)
    {
        ParameterUtils::DoubleToString((double)offsetScale_z, __value, __size);
        __result = true;
    }

    return __result;
}

bool OffsetScaleConfigType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "offsetScale_x") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            offsetScale_x = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "offsetScale_y") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            offsetScale_y = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "offsetScale_z") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            offsetScale_z = (float)dblValue; 
        }
    }

    return __result;
}

bool OffsetScaleConfigType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // offsetScale_x
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("offsetScale_x", ParameterParserDataType::Float, (double)offsetScale_x));
    }
    else if (PARAMETER_STRCMP(__name, "offsetScale_x") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)offsetScale_x));
    }

    // offsetScale_y
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("offsetScale_y", ParameterParserDataType::Float, (double)offsetScale_y));
    }
    else if (PARAMETER_STRCMP(__name, "offsetScale_y") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)offsetScale_y));
    }

    // offsetScale_z
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("offsetScale_z", ParameterParserDataType::Float, (double)offsetScale_z));
    }
    else if (PARAMETER_STRCMP(__name, "offsetScale_z") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)offsetScale_z));
    }

    return __result;
}

bool AccPositionConfigType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable") == 0)
    {
        ParameterUtils::DoubleToString((double)enable, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "staticOffsetEnable") == 0)
    {
        ParameterUtils::DoubleToString((double)staticOffsetEnable, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "staticOffsetRAW") == 0)
    {
        __result = staticOffsetRAW.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "scaleAdjEnable") == 0)
    {
        ParameterUtils::DoubleToString((double)scaleAdjEnable, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "scaleAdjFactor") == 0)
    {
        __result = scaleAdjFactor.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "referenceCnt") == 0)
    {
        ParameterUtils::DoubleToString((double)referenceCnt, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "segmentIntConfig") == 0)
    {
        __result = segmentIntConfig.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool AccPositionConfigType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            enable = (BOOL)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "staticOffsetEnable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            staticOffsetEnable = (BOOL)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "staticOffsetRAW") == 0)
    {
        __result = staticOffsetRAW.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "scaleAdjEnable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            scaleAdjEnable = (BOOL)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "scaleAdjFactor") == 0)
    {
        __result = scaleAdjFactor.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "referenceCnt") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            referenceCnt = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "segmentIntConfig") == 0)
    {
        __result = segmentIntConfig.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool AccPositionConfigType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // enable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("enable", ParameterParserDataType::Boolean, (double)enable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "enable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Boolean, (double)enable, 0));
    }

    // staticOffsetEnable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("staticOffsetEnable", ParameterParserDataType::Boolean, (double)staticOffsetEnable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "staticOffsetEnable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Boolean, (double)staticOffsetEnable, 0));
    }

    // staticOffsetRAW
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("staticOffsetRAW", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "staticOffsetRAW") == 0)
    {
        __result = staticOffsetRAW.GetInfo(&__path[__pos], __info);
    }

    // scaleAdjEnable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("scaleAdjEnable", ParameterParserDataType::Boolean, (double)scaleAdjEnable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "scaleAdjEnable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Boolean, (double)scaleAdjEnable, 0));
    }

    // scaleAdjFactor
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("scaleAdjFactor", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "scaleAdjFactor") == 0)
    {
        __result = scaleAdjFactor.GetInfo(&__path[__pos], __info);
    }

    // referenceCnt
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("referenceCnt", ParameterParserDataType::Int32, (double)referenceCnt, 0));
    }
    else if (PARAMETER_STRCMP(__name, "referenceCnt") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)referenceCnt, 0));
    }

    // segmentIntConfig
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("segmentIntConfig", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "segmentIntConfig") == 0)
    {
        __result = segmentIntConfig.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool ScaleFactorLevel1TriggerType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "triggerPt") == 0)
    {
        __result = triggerPt.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "triggerData") == 0)
    {
        __result = triggerData.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool ScaleFactorLevel1TriggerType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "triggerPt") == 0)
    {
        __result = triggerPt.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "triggerData") == 0)
    {
        __result = triggerData.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool ScaleFactorLevel1TriggerType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // triggerPt
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("triggerPt", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "triggerPt") == 0)
    {
        __result = triggerPt.GetInfo(&__path[__pos], __info);
    }

    // triggerData
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("triggerData", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "triggerData") == 0)
    {
        __result = triggerData.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool ScaleFactorTriggerType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "triggerPt") == 0)
    {
        __result = triggerPt.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "triggerData") == 0)
    {
        if (__index < triggerDataCount)
        {
            __result = triggerData[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool ScaleFactorTriggerType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "triggerPt") == 0)
    {
        __result = triggerPt.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "triggerData") == 0)
    {
        if (__index < triggerDataCount)
        {
            __result = triggerData[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool ScaleFactorTriggerType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // triggerPt
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("triggerPt", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "triggerPt") == 0)
    {
        __result = triggerPt.GetInfo(&__path[__pos], __info);
    }

    // triggerData
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("triggerData", ParameterParserDataType::Structure, true, false, triggerDataCount));
    }
    else if (PARAMETER_STRCMP(__name, "triggerData") == 0)
    {
        if (__index < triggerDataCount)
        {
            __result = triggerData[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, triggerDataCount));
        }
    }

    return __result;
}

bool Gyro2DOrientationConfigType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "staticOffsetEnable") == 0)
    {
        ParameterUtils::DoubleToString((double)staticOffsetEnable, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "staticOffsetRAW") == 0)
    {
        __result = staticOffsetRAW.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "scaleAdjEnable") == 0)
    {
        ParameterUtils::DoubleToString((double)scaleAdjEnable, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "scaleAdjFactor") == 0)
    {
        __result = scaleAdjFactor.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "accDataFusionEnable") == 0)
    {
        ParameterUtils::DoubleToString((double)accDataFusionEnable, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "accFusionWeight") == 0)
    {
        ParameterUtils::DoubleToString((double)accFusionWeight, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "segmentIntConfig") == 0)
    {
        __result = segmentIntConfig.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "FOVScaleAdjEnable") == 0)
    {
        ParameterUtils::DoubleToString((double)FOVScaleAdjEnable, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "FOVScaleAdjFactor") == 0)
    {
        __result = FOVScaleAdjFactor.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool Gyro2DOrientationConfigType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "staticOffsetEnable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            staticOffsetEnable = (BOOL)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "staticOffsetRAW") == 0)
    {
        __result = staticOffsetRAW.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "scaleAdjEnable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            scaleAdjEnable = (BOOL)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "scaleAdjFactor") == 0)
    {
        __result = scaleAdjFactor.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "accDataFusionEnable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            accDataFusionEnable = (BOOL)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "accFusionWeight") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            accFusionWeight = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "segmentIntConfig") == 0)
    {
        __result = segmentIntConfig.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "FOVScaleAdjEnable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            FOVScaleAdjEnable = (BOOL)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "FOVScaleAdjFactor") == 0)
    {
        __result = FOVScaleAdjFactor.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool Gyro2DOrientationConfigType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // staticOffsetEnable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("staticOffsetEnable", ParameterParserDataType::Boolean, (double)staticOffsetEnable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "staticOffsetEnable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Boolean, (double)staticOffsetEnable, 0));
    }

    // staticOffsetRAW
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("staticOffsetRAW", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "staticOffsetRAW") == 0)
    {
        __result = staticOffsetRAW.GetInfo(&__path[__pos], __info);
    }

    // scaleAdjEnable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("scaleAdjEnable", ParameterParserDataType::Boolean, (double)scaleAdjEnable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "scaleAdjEnable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Boolean, (double)scaleAdjEnable, 0));
    }

    // scaleAdjFactor
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("scaleAdjFactor", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "scaleAdjFactor") == 0)
    {
        __result = scaleAdjFactor.GetInfo(&__path[__pos], __info);
    }

    // accDataFusionEnable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("accDataFusionEnable", ParameterParserDataType::Boolean, (double)accDataFusionEnable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "accDataFusionEnable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Boolean, (double)accDataFusionEnable, 0));
    }

    // accFusionWeight
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("accFusionWeight", ParameterParserDataType::Float, (double)accFusionWeight));
    }
    else if (PARAMETER_STRCMP(__name, "accFusionWeight") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)accFusionWeight));
    }

    // segmentIntConfig
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("segmentIntConfig", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "segmentIntConfig") == 0)
    {
        __result = segmentIntConfig.GetInfo(&__path[__pos], __info);
    }

    // FOVScaleAdjEnable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("FOVScaleAdjEnable", ParameterParserDataType::Boolean, (double)FOVScaleAdjEnable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "FOVScaleAdjEnable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Boolean, (double)FOVScaleAdjEnable, 0));
    }

    // FOVScaleAdjFactor
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("FOVScaleAdjFactor", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "FOVScaleAdjFactor") == 0)
    {
        __result = FOVScaleAdjFactor.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool SenorRefreshConfigType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "gyro") == 0)
    {
        ParameterUtils::DoubleToString((double)gyro, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "accelerometer") == 0)
    {
        ParameterUtils::DoubleToString((double)accelerometer, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool SenorRefreshConfigType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "gyro") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            gyro = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "accelerometer") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            accelerometer = (INT32)dblValue; 
        }
    }

    return __result;
}

bool SenorRefreshConfigType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // gyro
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("gyro", ParameterParserDataType::Int32, (double)gyro, 0));
    }
    else if (PARAMETER_STRCMP(__name, "gyro") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)gyro, 0));
    }

    // accelerometer
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("accelerometer", ParameterParserDataType::Int32, (double)accelerometer, 0));
    }
    else if (PARAMETER_STRCMP(__name, "accelerometer") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)accelerometer, 0));
    }

    return __result;
}

bool AlignmentConfigType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "real_x_axis") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)real_x_axis, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "real_y_axis") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)real_y_axis, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "real_z_axis") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)real_z_axis, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool AlignmentConfigType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "real_x_axis") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            real_x_axis = (SensorAxisType)(UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "real_y_axis") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            real_y_axis = (SensorAxisType)(UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "real_z_axis") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            real_z_axis = (SensorAxisType)(UINT32)dblValue; 
        }
    }

    return __result;
}

bool AlignmentConfigType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // real_x_axis
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("real_x_axis", ParameterParserDataType::Enum, (double)(UINT32)real_x_axis, 0));
    }
    else if (PARAMETER_STRCMP(__name, "real_x_axis") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)real_x_axis, 0));
    }

    // real_y_axis
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("real_y_axis", ParameterParserDataType::Enum, (double)(UINT32)real_y_axis, 0));
    }
    else if (PARAMETER_STRCMP(__name, "real_y_axis") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)real_y_axis, 0));
    }

    // real_z_axis
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("real_z_axis", ParameterParserDataType::Enum, (double)(UINT32)real_z_axis, 0));
    }
    else if (PARAMETER_STRCMP(__name, "real_z_axis") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)real_z_axis, 0));
    }

    return __result;
}

bool AlignmentModeConfigType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "landscape") == 0)
    {
        __result = landscape.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "portrait") == 0)
    {
        __result = portrait.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "faceUpDown") == 0)
    {
        __result = faceUpDown.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool AlignmentModeConfigType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "landscape") == 0)
    {
        __result = landscape.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "portrait") == 0)
    {
        __result = portrait.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "faceUpDown") == 0)
    {
        __result = faceUpDown.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool AlignmentModeConfigType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // landscape
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("landscape", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "landscape") == 0)
    {
        __result = landscape.GetInfo(&__path[__pos], __info);
    }

    // portrait
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("portrait", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "portrait") == 0)
    {
        __result = portrait.GetInfo(&__path[__pos], __info);
    }

    // faceUpDown
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("faceUpDown", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "faceUpDown") == 0)
    {
        __result = faceUpDown.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool AccAlignmentConfigType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "orientationAlignment") == 0)
    {
        __result = orientationAlignment.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "modeAlignment") == 0)
    {
        __result = modeAlignment.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool AccAlignmentConfigType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "orientationAlignment") == 0)
    {
        __result = orientationAlignment.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "modeAlignment") == 0)
    {
        __result = modeAlignment.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool AccAlignmentConfigType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // orientationAlignment
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("orientationAlignment", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "orientationAlignment") == 0)
    {
        __result = orientationAlignment.GetInfo(&__path[__pos], __info);
    }

    // modeAlignment
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("modeAlignment", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "modeAlignment") == 0)
    {
        __result = modeAlignment.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool SensorsAlignmentConfigType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "gyro") == 0)
    {
        __result = gyro.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "accelerometer") == 0)
    {
        __result = accelerometer.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool SensorsAlignmentConfigType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "gyro") == 0)
    {
        __result = gyro.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "accelerometer") == 0)
    {
        __result = accelerometer.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool SensorsAlignmentConfigType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // gyro
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("gyro", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "gyro") == 0)
    {
        __result = gyro.GetInfo(&__path[__pos], __info);
    }

    // accelerometer
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("accelerometer", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "accelerometer") == 0)
    {
        __result = accelerometer.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool IMUConfigType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aligmentConfig") == 0)
    {
        __result = aligmentConfig.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "refreshRate") == 0)
    {
        __result = refreshRate.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "imu2DOrientation") == 0)
    {
        __result = imu2DOrientation.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "imuDevicePosition") == 0)
    {
        __result = imuDevicePosition.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool IMUConfigType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aligmentConfig") == 0)
    {
        __result = aligmentConfig.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "refreshRate") == 0)
    {
        __result = refreshRate.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "imu2DOrientation") == 0)
    {
        __result = imu2DOrientation.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "imuDevicePosition") == 0)
    {
        __result = imuDevicePosition.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool IMUConfigType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // aligmentConfig
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aligmentConfig", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "aligmentConfig") == 0)
    {
        __result = aligmentConfig.GetInfo(&__path[__pos], __info);
    }

    // refreshRate
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("refreshRate", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "refreshRate") == 0)
    {
        __result = refreshRate.GetInfo(&__path[__pos], __info);
    }

    // imu2DOrientation
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("imu2DOrientation", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "imu2DOrientation") == 0)
    {
        __result = imu2DOrientation.GetInfo(&__path[__pos], __info);
    }

    // imuDevicePosition
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("imuDevicePosition", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "imuDevicePosition") == 0)
    {
        __result = imuDevicePosition.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool SceneConfigType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "sceneInfo") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)sceneInfo, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "imuConfig") == 0)
    {
        __result = imuConfig.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "imageConfig") == 0)
    {
        __result = imageConfig.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool SceneConfigType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "sceneInfo") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            sceneInfo = (SceneInfoType)(UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "imuConfig") == 0)
    {
        __result = imuConfig.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "imageConfig") == 0)
    {
        __result = imageConfig.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool SceneConfigType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // sceneInfo
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("sceneInfo", ParameterParserDataType::Enum, (double)(UINT32)sceneInfo, 0));
    }
    else if (PARAMETER_STRCMP(__name, "sceneInfo") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)sceneInfo, 0));
    }

    // imuConfig
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("imuConfig", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "imuConfig") == 0)
    {
        __result = imuConfig.GetInfo(&__path[__pos], __info);
    }

    // imageConfig
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("imageConfig", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "imageConfig") == 0)
    {
        __result = imageConfig.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool TemporalAWBConfigType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "sceneConfig") == 0)
    {
        __result = sceneConfig.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "sceneChangeConfig") == 0)
    {
        __result = sceneChangeConfig.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "tempDecisionConfig") == 0)
    {
        __result = tempDecisionConfig.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool TemporalAWBConfigType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "sceneConfig") == 0)
    {
        __result = sceneConfig.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "sceneChangeConfig") == 0)
    {
        __result = sceneChangeConfig.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "tempDecisionConfig") == 0)
    {
        __result = tempDecisionConfig.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool TemporalAWBConfigType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // sceneConfig
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("sceneConfig", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "sceneConfig") == 0)
    {
        __result = sceneConfig.GetInfo(&__path[__pos], __info);
    }

    // sceneChangeConfig
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("sceneChangeConfig", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "sceneChangeConfig") == 0)
    {
        __result = sceneChangeConfig.GetInfo(&__path[__pos], __info);
    }

    // tempDecisionConfig
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("tempDecisionConfig", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "tempDecisionConfig") == 0)
    {
        __result = tempDecisionConfig.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool chromatixTemporalAWBV1Type::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "enable") == 0)
    {
        ParameterUtils::DoubleToString((double)enable, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "temporalAWB") == 0)
    {
        __result = temporalAWB.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool chromatixTemporalAWBV1Type::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "enable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            enable = (BOOL)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "temporalAWB") == 0)
    {
        __result = temporalAWB.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool chromatixTemporalAWBV1Type::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // module_version
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("module_version", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.GetInfo(&__path[__pos], __info);
    }

    // parameter_version
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("parameter_version", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.GetInfo(&__path[__pos], __info);
    }

    // enable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("enable", ParameterParserDataType::Boolean, (double)enable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "enable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Boolean, (double)enable, 0));
    }

    // temporalAWB
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("temporalAWB", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "temporalAWB") == 0)
    {
        __result = temporalAWB.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool chromatixTemporalAWBV1Type::module_versionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)major_revision, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)minor_revision, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)incr_revision, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatixTemporalAWBV1Type::module_versionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            major_revision = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            minor_revision = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            incr_revision = (INT32)dblValue; 
        }
    }

    return __result;
}

bool chromatixTemporalAWBV1Type::module_versionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // major_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("major_revision", ParameterParserDataType::Int32, (double)major_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)major_revision, 0));
    }

    // minor_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("minor_revision", ParameterParserDataType::Int32, (double)minor_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)minor_revision, 0));
    }

    // incr_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("incr_revision", ParameterParserDataType::Int32, (double)incr_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)incr_revision, 0));
    }

    return __result;
}

bool chromatixTemporalAWBV1Type::parameter_versionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        PARAMETER_STRCPY(__value, __size, revision);
        __result = true;
    }

    return __result;
}

bool chromatixTemporalAWBV1Type::parameter_versionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const /*__value*/)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        // Cannot modify strings, risk of memory leaks or corruption
    }

    return __result;
}

bool chromatixTemporalAWBV1Type::parameter_versionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("revision", ParameterParserDataType::String, revision));
    }
    else if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::String, revision));
    }

    return __result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @brief Read enum value
/// @param entry [in] Symbol table entry
/// @param enumValue [out] Enum value to read
/// @param alignment [in] Symbol table byte alignment
/// @return true if successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool ReadEnum_DecisionAggrType(
    ParameterFileSymbolTableEntry* const entry,
    DecisionAggrType& enumValue,
    BYTE const alignment)
{
    bool result {false};

    UINT32 uintValue {entry->ReadEnum(&result, alignment)};

    if (result)
    {
        switch (uintValue)
        {
        case static_cast<UINT32>(DecisionAggrType::AWBDecisionsBasedAggr):
            enumValue = DecisionAggrType::AWBDecisionsBasedAggr;
            result    = true;
            break;
        case static_cast<UINT32>(DecisionAggrType::GreyRegionsBasedAggr):
            enumValue = DecisionAggrType::GreyRegionsBasedAggr;
            result    = true;
            break;
        default:
            PARAMETER_LOG_ERROR(entry->SetManager, "Invalid value(% u) converting UINT32 to DecisionAggrType", uintValue);
            break;
        }
    }
    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @brief Read enum value
/// @param entry [in] Symbol table entry
/// @param enumValue [out] Enum value to read
/// @param alignment [in] Symbol table byte alignment
/// @return true if successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool ReadEnum_ImageOrienInputType(
    ParameterFileSymbolTableEntry* const entry,
    ImageOrienInputType& enumValue,
    BYTE const alignment)
{
    bool result {false};

    UINT32 uintValue {entry->ReadEnum(&result, alignment)};

    if (result)
    {
        switch (uintValue)
        {
        case static_cast<UINT32>(ImageOrienInputType::Homography):
            enumValue = ImageOrienInputType::Homography;
            result    = true;
            break;
        case static_cast<UINT32>(ImageOrienInputType::MotionVector):
            enumValue = ImageOrienInputType::MotionVector;
            result    = true;
            break;
        default:
            PARAMETER_LOG_ERROR(entry->SetManager, "Invalid value(% u) converting UINT32 to ImageOrienInputType", uintValue);
            break;
        }
    }
    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @brief Read enum value
/// @param entry [in] Symbol table entry
/// @param enumValue [out] Enum value to read
/// @param alignment [in] Symbol table byte alignment
/// @return true if successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool ReadEnum_SensorAxisType(
    ParameterFileSymbolTableEntry* const entry,
    SensorAxisType& enumValue,
    BYTE const alignment)
{
    bool result {false};

    UINT32 uintValue {entry->ReadEnum(&result, alignment)};

    if (result)
    {
        switch (uintValue)
        {
        case static_cast<UINT32>(SensorAxisType::Sensor_x_axis):
            enumValue = SensorAxisType::Sensor_x_axis;
            result    = true;
            break;
        case static_cast<UINT32>(SensorAxisType::Sensor_y_axis):
            enumValue = SensorAxisType::Sensor_y_axis;
            result    = true;
            break;
        case static_cast<UINT32>(SensorAxisType::Sensor_z_axis):
            enumValue = SensorAxisType::Sensor_z_axis;
            result    = true;
            break;
        default:
            PARAMETER_LOG_ERROR(entry->SetManager, "Invalid value(% u) converting UINT32 to SensorAxisType", uintValue);
            break;
        }
    }
    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @brief Read enum value
/// @param entry [in] Symbol table entry
/// @param enumValue [out] Enum value to read
/// @param alignment [in] Symbol table byte alignment
/// @return true if successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool ReadEnum_SceneInfoType(
    ParameterFileSymbolTableEntry* const entry,
    SceneInfoType& enumValue,
    BYTE const alignment)
{
    bool result {false};

    UINT32 uintValue {entry->ReadEnum(&result, alignment)};

    if (result)
    {
        switch (uintValue)
        {
        case static_cast<UINT32>(SceneInfoType::SceneInfoIMU):
            enumValue = SceneInfoType::SceneInfoIMU;
            result    = true;
            break;
        case static_cast<UINT32>(SceneInfoType::SceneInfoFusion):
            enumValue = SceneInfoType::SceneInfoFusion;
            result    = true;
            break;
        default:
            PARAMETER_LOG_ERROR(entry->SetManager, "Invalid value(% u) converting UINT32 to SceneInfoType", uintValue);
            break;
        }
    }
    return result;
}


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Default Constructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatixTemporalAWBV1TypeClass::chromatixTemporalAWBV1TypeClass(
    const CHAR* const name)
    : ParameterModule(name, MAJOR, MINOR, PATCH, nullptr)
{
    PARAMETER_INITIALIZE(SymbolTableID);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(enable);
    PARAMETER_INITIALIZE(temporalAWB);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Constructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatixTemporalAWBV1TypeClass::chromatixTemporalAWBV1TypeClass(
    const CHAR* const name,
    ModuleData* const moduleData)
    : ParameterModule(name, MAJOR, MINOR, PATCH, moduleData)
{
    PARAMETER_INITIALIZE(SymbolTableID);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(enable);
    PARAMETER_INITIALIZE(temporalAWB);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Destructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatixTemporalAWBV1TypeClass::~chromatixTemporalAWBV1TypeClass()
{
    if (Loaded)
    {
        UnloadModule();
    }
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// GetName
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
const CHAR* chromatixTemporalAWBV1TypeClass::GetName(
    const CHAR* const type)
{
    const CHAR* name = type;
    CHAR temp[ParameterFileSymbolTableEntry::TYPE_LEN + 1];
    if (PARAMETER_STRCMP(type, ModuleData::GetType(temp, "temporalAWBV1")) == 0)
    {
        name = "temporalAWBV1";
    }
    return name;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load HistoryResolutionType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool HistoryResolutionType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(hor);
    PARAMETER_INITIALIZE(vert);


    // Reading Array hor from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        horCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, horCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            horID = pointerEntry->ID;
            DupObjInfo* horDupInfo = pointerEntry->GetDupObject(horCount, file, line);
            if (horDupInfo != nullptr && horDupInfo->Object != nullptr)
            {
                hor = (INT32*)horDupInfo->Object;
                if (hor == nullptr)
                {
                    if (horDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "hor duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            horDupInfo->File, horDupInfo->Line, horDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "hor duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            horDupInfo->Line, horDupInfo->RefCount);
                    }
                }
            }

            if (hor == nullptr)
            {
                if (result && horCount > 0)
                {
                    hor = pointerEntry->ReadArray<INT32>(horCount, alignment);
                    result = hor != nullptr;
                }
                if (!result || hor == nullptr)
                {
                    if (horCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate hor\n");
                    }
                    horCount = 0;
                }
            }
        }
        if (hor == nullptr)
        {
            horCount = 0;
        }
    }

    // Reading Array vert from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        vertCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, vertCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            vertID = pointerEntry->ID;
            DupObjInfo* vertDupInfo = pointerEntry->GetDupObject(vertCount, file, line);
            if (vertDupInfo != nullptr && vertDupInfo->Object != nullptr)
            {
                vert = (INT32*)vertDupInfo->Object;
                if (vert == nullptr)
                {
                    if (vertDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "vert duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            vertDupInfo->File, vertDupInfo->Line, vertDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "vert duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            vertDupInfo->Line, vertDupInfo->RefCount);
                    }
                }
            }

            if (vert == nullptr)
            {
                if (result && vertCount > 0)
                {
                    vert = pointerEntry->ReadArray<INT32>(vertCount, alignment);
                    result = vert != nullptr;
                }
                if (!result || vert == nullptr)
                {
                    if (vertCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate vert\n");
                    }
                    vertCount = 0;
                }
            }
        }
        if (vert == nullptr)
        {
            vertCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load HistoryConfigType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool HistoryConfigType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(histResolution);
    PARAMETER_INITIALIZE(sceneChangeRGBGTh);
    PARAMETER_INITIALIZE(sceneChangeLuxTh);

    result = histResolution.Load(entry, alignment);
    SYMBOL_TABLE_ENTRY_READ(entry, result, sceneChangeRGBGTh, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, sceneChangeLuxTh, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load WeightLUTGrayRatioTriggerType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool WeightLUTGrayRatioTriggerType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(triggerPt);
    PARAMETER_INITIALIZE(triggerData);

    result = triggerPt.Load(entry, alignment);
    if (result)
    {
        result = triggerData.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load WeightLUTFOVChangeTriggerType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool WeightLUTFOVChangeTriggerType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(triggerPt);
    PARAMETER_INITIALIZE(triggerData);

    result = triggerPt.Load(entry, alignment);

    // Reading Array triggerData from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        triggerDataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, triggerDataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            triggerDataID = pointerEntry->ID;
            DupObjInfo* triggerDataDupInfo = pointerEntry->GetDupObject(triggerDataCount, file, line);
            if (triggerDataDupInfo != nullptr && triggerDataDupInfo->Object != nullptr)
            {
                triggerData = (WeightLUTGrayRatioTriggerType*)triggerDataDupInfo->Object;
                if (triggerData == nullptr)
                {
                    if (triggerDataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "triggerData duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            triggerDataDupInfo->File, triggerDataDupInfo->Line, triggerDataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "triggerData duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            triggerDataDupInfo->Line, triggerDataDupInfo->RefCount);
                    }
                }
            }

            if (triggerData == nullptr)
            {
                if (result && triggerDataCount > 0)
                {
                    triggerData = PARAMETER_NEW WeightLUTGrayRatioTriggerType[triggerDataCount];
                    (void)pointerEntry->SetDupObject(triggerData, triggerDataCount, file, line);
                }
                if (!result || triggerData == nullptr)
                {
                    if (triggerDataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate triggerData\n");
                    }
                    triggerDataCount = 0;
                }
                for (UINT32 i = 0; result && i < triggerDataCount; i++)
                {
                    result = triggerData[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (triggerData == nullptr)
        {
            triggerDataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load WeightLUTLuxTriggerType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool WeightLUTLuxTriggerType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(triggerPt);
    PARAMETER_INITIALIZE(triggerData);

    result = triggerPt.Load(entry, alignment);

    // Reading Array triggerData from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        triggerDataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, triggerDataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            triggerDataID = pointerEntry->ID;
            DupObjInfo* triggerDataDupInfo = pointerEntry->GetDupObject(triggerDataCount, file, line);
            if (triggerDataDupInfo != nullptr && triggerDataDupInfo->Object != nullptr)
            {
                triggerData = (WeightLUTFOVChangeTriggerType*)triggerDataDupInfo->Object;
                if (triggerData == nullptr)
                {
                    if (triggerDataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "triggerData duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            triggerDataDupInfo->File, triggerDataDupInfo->Line, triggerDataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "triggerData duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            triggerDataDupInfo->Line, triggerDataDupInfo->RefCount);
                    }
                }
            }

            if (triggerData == nullptr)
            {
                if (result && triggerDataCount > 0)
                {
                    triggerData = PARAMETER_NEW WeightLUTFOVChangeTriggerType[triggerDataCount];
                    (void)pointerEntry->SetDupObject(triggerData, triggerDataCount, file, line);
                }
                if (!result || triggerData == nullptr)
                {
                    if (triggerDataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate triggerData\n");
                    }
                    triggerDataCount = 0;
                }
                for (UINT32 i = 0; result && i < triggerDataCount; i++)
                {
                    result = triggerData[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (triggerData == nullptr)
        {
            triggerDataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load WeightLUTTriggerType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool WeightLUTTriggerType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(triggerPt);
    PARAMETER_INITIALIZE(triggerData);

    result = triggerPt.Load(entry, alignment);

    // Reading Array triggerData from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        triggerDataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, triggerDataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            triggerDataID = pointerEntry->ID;
            DupObjInfo* triggerDataDupInfo = pointerEntry->GetDupObject(triggerDataCount, file, line);
            if (triggerDataDupInfo != nullptr && triggerDataDupInfo->Object != nullptr)
            {
                triggerData = (WeightLUTLuxTriggerType*)triggerDataDupInfo->Object;
                if (triggerData == nullptr)
                {
                    if (triggerDataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "triggerData duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            triggerDataDupInfo->File, triggerDataDupInfo->Line, triggerDataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "triggerData duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            triggerDataDupInfo->Line, triggerDataDupInfo->RefCount);
                    }
                }
            }

            if (triggerData == nullptr)
            {
                if (result && triggerDataCount > 0)
                {
                    triggerData = PARAMETER_NEW WeightLUTLuxTriggerType[triggerDataCount];
                    (void)pointerEntry->SetDupObject(triggerData, triggerDataCount, file, line);
                }
                if (!result || triggerData == nullptr)
                {
                    if (triggerDataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate triggerData\n");
                    }
                    triggerDataCount = 0;
                }
                for (UINT32 i = 0; result && i < triggerDataCount; i++)
                {
                    result = triggerData[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (triggerData == nullptr)
        {
            triggerDataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load DecisionsAggBasedType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool DecisionsAggBasedType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(weight);
    PARAMETER_INITIALIZE(historyConfig);

    result = weight.Load(entry, alignment);
    if (result)
    {
        result = historyConfig.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load DecisionGeneralParamsType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool DecisionGeneralParamsType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(histUpdateTolerance);

    SYMBOL_TABLE_ENTRY_READ(entry, result, histUpdateTolerance, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load TemporalDecisionConfigType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool TemporalDecisionConfigType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(generalParams);
    PARAMETER_INITIALIZE(aggregation);
    PARAMETER_INITIALIZE(decisionsAggBased);

    result = generalParams.Load(entry, alignment);
    if (result)
    {
        result = modtemporalawbv1::ReadEnum_DecisionAggrType(entry, aggregation, alignment);
    }
    if (result)
    {
        result = decisionsAggBased.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load SCGeneralParamsType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool SCGeneralParamsType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(initFrameSkipCnt);
    PARAMETER_INITIALIZE(globalSCFrameSkipCnt);

    SYMBOL_TABLE_ENTRY_READ(entry, result, initFrameSkipCnt, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, globalSCFrameSkipCnt, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load GlobalSceneChangeParamsType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool GlobalSceneChangeParamsType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(AFDistSCEnable);
    PARAMETER_INITIALIZE(contSCEnable);
    PARAMETER_INITIALIZE(contSCmaxTimeTh);
    PARAMETER_INITIALIZE(samePosSCEnable);

    SYMBOL_TABLE_ENTRY_READ(entry, result, AFDistSCEnable, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, contSCEnable, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, contSCmaxTimeTh, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, samePosSCEnable, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load GlobalSceneChangeType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool GlobalSceneChangeType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(luxSCDetector);
    PARAMETER_INITIALIZE(accSCDetector);
    PARAMETER_INITIALIZE(sceneChangeParams);

    result = luxSCDetector.Load(entry, alignment);
    if (result)
    {
        result = accSCDetector.Load(entry, alignment);
    }
    if (result)
    {
        result = sceneChangeParams.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load LocalSceneChangeType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool LocalSceneChangeType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(luxSCDetector);
    PARAMETER_INITIALIZE(orientSCDetector);

    result = luxSCDetector.Load(entry, alignment);
    if (result)
    {
        result = orientSCDetector.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load SceneChangeConfigType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool SceneChangeConfigType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(localSCDetector);
    PARAMETER_INITIALIZE(globalSCDetector);
    PARAMETER_INITIALIZE(generalParams);

    result = localSCDetector.Load(entry, alignment);
    if (result)
    {
        result = globalSCDetector.Load(entry, alignment);
    }
    if (result)
    {
        result = generalParams.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load ImageConfigType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool ImageConfigType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(inputType);
    PARAMETER_INITIALIZE(scale_x);
    PARAMETER_INITIALIZE(scale_y);
    PARAMETER_INITIALIZE(confThresholdCVP);
    PARAMETER_INITIALIZE(validateUsingIMU);
    PARAMETER_INITIALIZE(weightImage);

    result = modtemporalawbv1::ReadEnum_ImageOrienInputType(entry, inputType, alignment);
    SYMBOL_TABLE_ENTRY_READ(entry, result, scale_x, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, scale_y, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, confThresholdCVP, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, validateUsingIMU, alignment)
    if (result)
    {
        result = weightImage.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load SegmentIntegrateConfigType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool SegmentIntegrateConfigType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(enable);
    PARAMETER_INITIALIZE(noiseThreshold_x);
    PARAMETER_INITIALIZE(noiseThreshold_y);
    PARAMETER_INITIALIZE(noiseThreshold_z);
    PARAMETER_INITIALIZE(sampleCntThreshold);

    SYMBOL_TABLE_ENTRY_READ(entry, result, enable, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, noiseThreshold_x, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, noiseThreshold_y, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, noiseThreshold_z, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, sampleCntThreshold, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load OffsetScaleConfigType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool OffsetScaleConfigType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(offsetScale_x);
    PARAMETER_INITIALIZE(offsetScale_y);
    PARAMETER_INITIALIZE(offsetScale_z);

    SYMBOL_TABLE_ENTRY_READ(entry, result, offsetScale_x, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, offsetScale_y, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, offsetScale_z, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load AccPositionConfigType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool AccPositionConfigType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(enable);
    PARAMETER_INITIALIZE(staticOffsetEnable);
    PARAMETER_INITIALIZE(staticOffsetRAW);
    PARAMETER_INITIALIZE(scaleAdjEnable);
    PARAMETER_INITIALIZE(scaleAdjFactor);
    PARAMETER_INITIALIZE(referenceCnt);
    PARAMETER_INITIALIZE(segmentIntConfig);

    SYMBOL_TABLE_ENTRY_READ(entry, result, enable, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, staticOffsetEnable, alignment)
    if (result)
    {
        result = staticOffsetRAW.Load(entry, alignment);
    }
    SYMBOL_TABLE_ENTRY_READ(entry, result, scaleAdjEnable, alignment)
    if (result)
    {
        result = scaleAdjFactor.Load(entry, alignment);
    }
    SYMBOL_TABLE_ENTRY_READ(entry, result, referenceCnt, alignment)
    if (result)
    {
        result = segmentIntConfig.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load ScaleFactorLevel1TriggerType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool ScaleFactorLevel1TriggerType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(triggerPt);
    PARAMETER_INITIALIZE(triggerData);

    result = triggerPt.Load(entry, alignment);
    if (result)
    {
        result = triggerData.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load ScaleFactorTriggerType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool ScaleFactorTriggerType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(triggerPt);
    PARAMETER_INITIALIZE(triggerData);

    result = triggerPt.Load(entry, alignment);

    // Reading Array triggerData from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        triggerDataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, triggerDataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            triggerDataID = pointerEntry->ID;
            DupObjInfo* triggerDataDupInfo = pointerEntry->GetDupObject(triggerDataCount, file, line);
            if (triggerDataDupInfo != nullptr && triggerDataDupInfo->Object != nullptr)
            {
                triggerData = (ScaleFactorLevel1TriggerType*)triggerDataDupInfo->Object;
                if (triggerData == nullptr)
                {
                    if (triggerDataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "triggerData duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            triggerDataDupInfo->File, triggerDataDupInfo->Line, triggerDataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "triggerData duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            triggerDataDupInfo->Line, triggerDataDupInfo->RefCount);
                    }
                }
            }

            if (triggerData == nullptr)
            {
                if (result && triggerDataCount > 0)
                {
                    triggerData = PARAMETER_NEW ScaleFactorLevel1TriggerType[triggerDataCount];
                    (void)pointerEntry->SetDupObject(triggerData, triggerDataCount, file, line);
                }
                if (!result || triggerData == nullptr)
                {
                    if (triggerDataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate triggerData\n");
                    }
                    triggerDataCount = 0;
                }
                for (UINT32 i = 0; result && i < triggerDataCount; i++)
                {
                    result = triggerData[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (triggerData == nullptr)
        {
            triggerDataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load Gyro2DOrientationConfigType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool Gyro2DOrientationConfigType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(staticOffsetEnable);
    PARAMETER_INITIALIZE(staticOffsetRAW);
    PARAMETER_INITIALIZE(scaleAdjEnable);
    PARAMETER_INITIALIZE(scaleAdjFactor);
    PARAMETER_INITIALIZE(accDataFusionEnable);
    PARAMETER_INITIALIZE(accFusionWeight);
    PARAMETER_INITIALIZE(segmentIntConfig);
    PARAMETER_INITIALIZE(FOVScaleAdjEnable);
    PARAMETER_INITIALIZE(FOVScaleAdjFactor);

    SYMBOL_TABLE_ENTRY_READ(entry, result, staticOffsetEnable, alignment)
    if (result)
    {
        result = staticOffsetRAW.Load(entry, alignment);
    }
    SYMBOL_TABLE_ENTRY_READ(entry, result, scaleAdjEnable, alignment)
    if (result)
    {
        result = scaleAdjFactor.Load(entry, alignment);
    }
    SYMBOL_TABLE_ENTRY_READ(entry, result, accDataFusionEnable, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, accFusionWeight, alignment)
    if (result)
    {
        result = segmentIntConfig.Load(entry, alignment);
    }
    SYMBOL_TABLE_ENTRY_READ(entry, result, FOVScaleAdjEnable, alignment)
    if (result)
    {
        result = FOVScaleAdjFactor.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load SenorRefreshConfigType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool SenorRefreshConfigType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(gyro);
    PARAMETER_INITIALIZE(accelerometer);

    SYMBOL_TABLE_ENTRY_READ(entry, result, gyro, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, accelerometer, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load AlignmentConfigType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool AlignmentConfigType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(real_x_axis);
    PARAMETER_INITIALIZE(real_y_axis);
    PARAMETER_INITIALIZE(real_z_axis);

    result = modtemporalawbv1::ReadEnum_SensorAxisType(entry, real_x_axis, alignment);
    if (result)
    {
        result = modtemporalawbv1::ReadEnum_SensorAxisType(entry, real_y_axis, alignment);
    }
    if (result)
    {
        result = modtemporalawbv1::ReadEnum_SensorAxisType(entry, real_z_axis, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load AlignmentModeConfigType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool AlignmentModeConfigType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(landscape);
    PARAMETER_INITIALIZE(portrait);
    PARAMETER_INITIALIZE(faceUpDown);

    result = landscape.Load(entry, alignment);
    if (result)
    {
        result = portrait.Load(entry, alignment);
    }
    if (result)
    {
        result = faceUpDown.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load AccAlignmentConfigType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool AccAlignmentConfigType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(orientationAlignment);
    PARAMETER_INITIALIZE(modeAlignment);

    result = orientationAlignment.Load(entry, alignment);
    if (result)
    {
        result = modeAlignment.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load SensorsAlignmentConfigType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool SensorsAlignmentConfigType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(gyro);
    PARAMETER_INITIALIZE(accelerometer);

    result = gyro.Load(entry, alignment);
    if (result)
    {
        result = accelerometer.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load IMUConfigType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool IMUConfigType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(aligmentConfig);
    PARAMETER_INITIALIZE(refreshRate);
    PARAMETER_INITIALIZE(imu2DOrientation);
    PARAMETER_INITIALIZE(imuDevicePosition);

    result = aligmentConfig.Load(entry, alignment);
    if (result)
    {
        result = refreshRate.Load(entry, alignment);
    }
    if (result)
    {
        result = imu2DOrientation.Load(entry, alignment);
    }
    if (result)
    {
        result = imuDevicePosition.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load SceneConfigType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool SceneConfigType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(sceneInfo);
    PARAMETER_INITIALIZE(imuConfig);
    PARAMETER_INITIALIZE(imageConfig);

    result = modtemporalawbv1::ReadEnum_SceneInfoType(entry, sceneInfo, alignment);
    if (result)
    {
        result = imuConfig.Load(entry, alignment);
    }
    if (result)
    {
        result = imageConfig.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load TemporalAWBConfigType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool TemporalAWBConfigType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(sceneConfig);
    PARAMETER_INITIALIZE(sceneChangeConfig);
    PARAMETER_INITIALIZE(tempDecisionConfig);

    result = sceneConfig.Load(entry, alignment);
    if (result)
    {
        result = sceneChangeConfig.Load(entry, alignment);
    }
    if (result)
    {
        result = tempDecisionConfig.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatixTemporalAWBV1Type
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatixTemporalAWBV1Type::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(enable);
    PARAMETER_INITIALIZE(temporalAWB);

    result = module_version.Load(entry, alignment);
    if (result)
    {
        result = parameter_version.Load(entry, alignment);
    }
    SYMBOL_TABLE_ENTRY_READ(entry, result, enable, alignment)
    if (result)
    {
        result = temporalAWB.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load module_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatixTemporalAWBV1Type::module_versionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(major_revision);
    PARAMETER_INITIALIZE(minor_revision);
    PARAMETER_INITIALIZE(incr_revision);

    SYMBOL_TABLE_ENTRY_READ(entry, result, major_revision, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, minor_revision, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, incr_revision, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load parameter_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatixTemporalAWBV1Type::parameter_versionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(revision);


    // Reading String revision from symbol table
    {
        UINT32 count = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, count, alignment)
        ParameterFileSymbolTableEntry stringPointerEntryCls;
        ParameterFileSymbolTableEntry* const stringPointerEntry = &stringPointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(stringPointerEntryCls, entry, alignment);
        }
        SYMBOL_TABLE_ENTRY_READ_STRING(stringPointerEntry, result, revision, count, alignment)
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload HistoryResolutionType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void HistoryResolutionType::Unload(ParameterFileSymbolTable* const __table)
{
    if (__table != nullptr && __table->ReleaseDupObject(hor))
    {
        PARAMETER_DELETE[] hor;
    }
    hor = nullptr;
    if (__table != nullptr && __table->ReleaseDupObject(vert))
    {
        PARAMETER_DELETE[] vert;
    }
    vert = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload HistoryConfigType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void HistoryConfigType::Unload(ParameterFileSymbolTable* const __table)
{
    histResolution.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload WeightLUTFOVChangeTriggerType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void WeightLUTFOVChangeTriggerType::Unload(ParameterFileSymbolTable* const __table)
{
    if (__table != nullptr && __table->ReleaseDupObject(triggerData))
    {
        PARAMETER_DELETE[] triggerData;
    }
    triggerData = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload WeightLUTLuxTriggerType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void WeightLUTLuxTriggerType::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < triggerDataCount; i++)
    {
        triggerData[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(triggerData))
    {
        PARAMETER_DELETE[] triggerData;
    }
    triggerData = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload WeightLUTTriggerType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void WeightLUTTriggerType::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < triggerDataCount; i++)
    {
        triggerData[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(triggerData))
    {
        PARAMETER_DELETE[] triggerData;
    }
    triggerData = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload DecisionsAggBasedType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void DecisionsAggBasedType::Unload(ParameterFileSymbolTable* const __table)
{
    weight.Unload(__table);
    historyConfig.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload TemporalDecisionConfigType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void TemporalDecisionConfigType::Unload(ParameterFileSymbolTable* const __table)
{
    decisionsAggBased.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload GlobalSceneChangeType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void GlobalSceneChangeType::Unload(ParameterFileSymbolTable* const __table)
{
    luxSCDetector.Unload(__table);
    accSCDetector.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload LocalSceneChangeType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void LocalSceneChangeType::Unload(ParameterFileSymbolTable* const __table)
{
    luxSCDetector.Unload(__table);
    orientSCDetector.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload SceneChangeConfigType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void SceneChangeConfigType::Unload(ParameterFileSymbolTable* const __table)
{
    localSCDetector.Unload(__table);
    globalSCDetector.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload ImageConfigType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void ImageConfigType::Unload(ParameterFileSymbolTable* const __table)
{
    weightImage.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload ScaleFactorTriggerType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void ScaleFactorTriggerType::Unload(ParameterFileSymbolTable* const __table)
{
    if (__table != nullptr && __table->ReleaseDupObject(triggerData))
    {
        PARAMETER_DELETE[] triggerData;
    }
    triggerData = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload Gyro2DOrientationConfigType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void Gyro2DOrientationConfigType::Unload(ParameterFileSymbolTable* const __table)
{
    scaleAdjFactor.Unload(__table);
    FOVScaleAdjFactor.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload IMUConfigType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void IMUConfigType::Unload(ParameterFileSymbolTable* const __table)
{
    imu2DOrientation.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload SceneConfigType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void SceneConfigType::Unload(ParameterFileSymbolTable* const __table)
{
    imuConfig.Unload(__table);
    imageConfig.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload TemporalAWBConfigType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void TemporalAWBConfigType::Unload(ParameterFileSymbolTable* const __table)
{
    sceneConfig.Unload(__table);
    sceneChangeConfig.Unload(__table);
    tempDecisionConfig.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload chromatixTemporalAWBV1Type
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatixTemporalAWBV1Type::Unload(ParameterFileSymbolTable* const __table)
{
    parameter_version.Unload(__table);
    temporalAWB.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload parameter_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatixTemporalAWBV1Type::parameter_versionStruct::Unload(ParameterFileSymbolTable* const __table)
{
    if (__table != nullptr && __table->ReleaseDupObject(revision))
    {
        PARAMETER_DELETE[] revision;
    }
    revision = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Release the ParameterModule object
/// Requires that this object was created via a ParameterSetManager::GetModule call
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatixTemporalAWBV1Type::Release()
{
    ((chromatixTemporalAWBV1TypeClass*)this)->Release();
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Returns the ParameterModule::Modified value
/// The Modified value is incremented when the module's data or pointer values change
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
UINT32 chromatixTemporalAWBV1Type::GetModified()
{
    return ((chromatixTemporalAWBV1TypeClass*)this)->Modified;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Create module, and return a new object
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
ParameterModule* chromatixTemporalAWBV1TypeClass::Create(
    ModuleData*    moduleData,
    DefaultModule* const defModule) const
{
    chromatixTemporalAWBV1TypeClass* cls = nullptr;

    if (PARAMETER_STRCMP(Type, moduleData->Type) == 0 && Version.Value == moduleData->Version.Value)
    {
        const UINT32 id = moduleData->DuplicateID > 0 ? moduleData->DuplicateID : moduleData->ID;

        ParameterModule* const module = defModule->Find(id);
        if (module != nullptr)
        {
            cls = (chromatixTemporalAWBV1TypeClass*)module;
        }
        else
        {
            cls = PARAMETER_NEW chromatixTemporalAWBV1TypeClass(GetName(moduleData->Type), moduleData);
            cls->SymbolTableID = id;
            defModule->AddModule((ParameterModule*)cls);
        }
    }
    else if (Version.Value != moduleData->Version.Value)
    {
        PARAMETER_LOG_ERROR(moduleData->SetManager, "Unable to create chromatixTemporalAWBV1TypeClass, binary version (%lld) does not match source version (%lld)\n",
            moduleData->Version.Value, Version.Value);
    }
    else
    {
        PARAMETER_LOG_ERROR(moduleData->SetManager, "Unable to create chromatixTemporalAWBV1TypeClass, binary name (%s) does not match source name (%s)\n",
            moduleData->Type, Type);
    }

    return (ParameterModule*)cls;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load module data, return true is successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatixTemporalAWBV1TypeClass::LoadModule(
    ParameterFileSymbolTable* const table)
{
    bool result = true;

    if (!Loaded)
    {
        BYTE const alignment = table->Alignment;
        chromatixTemporalAWBV1TypeClass* const cls = this;

        ParameterFileSymbolTableEntry  entryObj;
        ParameterFileSymbolTableEntry* const entry = &entryObj;
        // With EzTune enabled, the unused upper byte of SymbolTableID value can change, so clear it
        result = table->Find(entryObj, SymbolTableID & 0x00ffffff);

        if (!result)
        {
            PARAMETER_LOG_ERROR(entry->SetManager, "chromatixTemporalAWBV1TypeClass::LoadModule Failed to find module ID (%d) in Symbol Table\n", SymbolTableID);
        }

        if (result)
        {
            result = cls->Load(entry, alignment);
        }
        Modified++;
        Loaded = true;
    }

    if (!result)
    {
        /// Module failed to fully load, unload it
        UnloadModule();
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload module data
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatixTemporalAWBV1TypeClass::UnloadModule()
{
    if (Loaded)
    {
        if (Data != nullptr && Data->SymbolTable != nullptr)
        {
            Unload(Data->SymbolTable);
        }
        else
        {
            PARAMETER_LOG_ERROR(Data != nullptr ? Data->SetManager : nullptr, "UnloadModule %s called with nullptr "
                "Data->SymbolTable object\n", Name);
            Unload(nullptr);
        }
        Loaded = false;
    }
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// /// Release the ParameterModule object
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatixTemporalAWBV1TypeClass::Release()
{
    ParameterModule::Release();
}

MODTEMPORALAWBV1_NAMESPACE_END
